==> jc-1.4.0.tar.gz: java/security/cert/CertPathBuilderSpi.h <==
// public abstract class java.security.cert.CertPathBuilderSpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c7e80a5b9e74a7c5 java_security_cert_CertPathBuilderSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CertPathBuilderSpi_H_
#define _JC_java_security_cert_CertPathBuilderSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_cert_CertPathBuilderResult$object;
struct _jc_java_security_cert_CertPathParameters$object;

// Typedefs
typedef struct _jc_java_security_cert_CertPathBuilderSpi$sub_refs	_jc_java_security_cert_CertPathBuilderSpi$sub_refs;
typedef struct _jc_java_security_cert_CertPathBuilderSpi$sub_nonrefs	_jc_java_security_cert_CertPathBuilderSpi$sub_nonrefs;
typedef struct _jc_java_security_cert_CertPathBuilderSpi$refs	_jc_java_security_cert_CertPathBuilderSpi$refs;
typedef struct _jc_java_security_cert_CertPathBuilderSpi$nonrefs	_jc_java_security_cert_CertPathBuilderSpi$nonrefs;
typedef struct _jc_java_security_cert_CertPathBuilderSpi$object	_jc_java_security_cert_CertPathBuilderSpi$object;

typedef const struct _jc_java_security_cert_CertPathBuilderSpi$vmethods	_jc_java_security_cert_CertPathBuilderSpi$vmethods;
typedef const struct _jc_java_security_cert_CertPathBuilderSpi$vtable	_jc_java_security_cert_CertPathBuilderSpi$vtable;
typedef const struct _jc_java_security_cert_CertPathBuilderSpi$vtype	_jc_java_security_cert_CertPathBuilderSpi$vtype;

// Constructors
extern void _jc_java_security_cert_CertPathBuilderSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_CertPathBuilderSpi$object *);

// Virtual methods
extern struct _jc_object *_jc_java_security_cert_CertPathBuilderSpi$method$engineBuild$44baf76f896e88ca(_jc_env *, struct _jc_java_security_cert_CertPathBuilderSpi$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertPathBuilderSpi$method_info$engineBuild$44baf76f896e88ca;

// Virtual methods structure
struct _jc_java_security_cert_CertPathBuilderSpi$vmethods {
	struct _jc_object	*(*engineBuild$44baf76f896e88ca)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderSpi$object *, struct _jc_object *);
};

// Vtable
struct _jc_java_security_cert_CertPathBuilderSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertPathBuilderSpi$vmethods	java_security_cert_CertPathBuilderSpi;
};

// Vtype
struct _jc_java_security_cert_CertPathBuilderSpi$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertPathBuilderSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertPathBuilderSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertPathBuilderSpi$refs {
    _jc_java_security_cert_CertPathBuilderSpi$sub_refs	java_security_cert_CertPathBuilderSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertPathBuilderSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertPathBuilderSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertPathBuilderSpi$sub_nonrefs	java_security_cert_CertPathBuilderSpi;
};

// Object instance structure
struct _jc_java_security_cert_CertPathBuilderSpi$object {
	_jc_java_security_cert_CertPathBuilderSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertPathBuilderSpi$vtype	*vtype;
	_jc_java_security_cert_CertPathBuilderSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertPathBuilderSpi$vtype _jc_java_security_cert_CertPathBuilderSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertPathBuilderSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertPathBuilderSpi$class_object;

#endif	/* _JC_java_security_cert_CertPathBuilderSpi_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/CertPathBuilderSpi.h <==
// public abstract class java.security.cert.CertPathBuilderSpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c7e80a5b9e74a7c5 java_security_cert_CertPathBuilderSpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_CertPathBuilderSpi_H_
#define _JC_java_security_cert_CertPathBuilderSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_cert_CertPathBuilderResult$object;
struct _jc_java_security_cert_CertPathParameters$object;

// Typedefs
typedef struct _jc_java_security_cert_CertPathBuilderSpi$sub_refs	_jc_java_security_cert_CertPathBuilderSpi$sub_refs;
typedef struct _jc_java_security_cert_CertPathBuilderSpi$sub_nonrefs	_jc_java_security_cert_CertPathBuilderSpi$sub_nonrefs;
typedef struct _jc_java_security_cert_CertPathBuilderSpi$refs	_jc_java_security_cert_CertPathBuilderSpi$refs;
typedef struct _jc_java_security_cert_CertPathBuilderSpi$nonrefs	_jc_java_security_cert_CertPathBuilderSpi$nonrefs;
typedef struct _jc_java_security_cert_CertPathBuilderSpi$object	_jc_java_security_cert_CertPathBuilderSpi$object;

typedef const struct _jc_java_security_cert_CertPathBuilderSpi$vmethods	_jc_java_security_cert_CertPathBuilderSpi$vmethods;
typedef const struct _jc_java_security_cert_CertPathBuilderSpi$vtable	_jc_java_security_cert_CertPathBuilderSpi$vtable;
typedef const struct _jc_java_security_cert_CertPathBuilderSpi$vtype	_jc_java_security_cert_CertPathBuilderSpi$vtype;

// Constructors
extern void _jc_java_security_cert_CertPathBuilderSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_CertPathBuilderSpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_security_cert_CertPathBuilderSpi$method$engineBuild$44baf76f896e88ca(_jc_env *, struct _jc_java_security_cert_CertPathBuilderSpi$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_CertPathBuilderSpi$method_info$engineBuild$44baf76f896e88ca;

// Virtual methods structure
struct _jc_java_security_cert_CertPathBuilderSpi$vmethods {
	struct _jc_object	*(*engineBuild$44baf76f896e88ca)(_jc_env *, struct _jc_java_security_cert_CertPathBuilderSpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_CertPathBuilderSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertPathBuilderSpi$vmethods	java_security_cert_CertPathBuilderSpi;
};

// Vtype
struct _jc_java_security_cert_CertPathBuilderSpi$vtype {
	_jc_type			type;
	_jc_java_security_cert_CertPathBuilderSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_CertPathBuilderSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_security_cert_CertPathBuilderSpi$refs {
    _jc_java_security_cert_CertPathBuilderSpi$sub_refs	java_security_cert_CertPathBuilderSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_CertPathBuilderSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_CertPathBuilderSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertPathBuilderSpi$sub_nonrefs	java_security_cert_CertPathBuilderSpi;
};

// Object instance structure
struct _jc_java_security_cert_CertPathBuilderSpi$object {
	_jc_java_security_cert_CertPathBuilderSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_CertPathBuilderSpi$vtype	*vtype;
	_jc_java_security_cert_CertPathBuilderSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_CertPathBuilderSpi$vtype _jc_java_security_cert_CertPathBuilderSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_CertPathBuilderSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_CertPathBuilderSpi$class_object;

#endif	/* _JC_java_security_cert_CertPathBuilderSpi_H_ */
